A raster time series object is created by combining a RasterStack or RasterBrick objct, defined in raster and a xts object in xts-package.
RasterStack or RasterBrick can be created by using stack and brick functions, respectively in raster-package. If a character vector including the name of raster files is used for x, stack function is internally called by rts. time information is handled by xts object. The date/time values in the vector of time should be correspond to the raster files (i.e. first date/time for first raster, ...) and have the same length as the number of rasters in x.
If a name of a raster time series file is provided for the x argument, it acts the same as coderead.rts.
If x is the name of Raster Time Series file (a character), it calls read.rts to read the file. By default, the Raster Time Series is read as the class of SpatRasterTS, but the user can provide cls argument to specify a different rts class (e.g., cls='RasterBrickTS')